get_thread: Get all skeets in a thread

View source: R/feed.r

get_threadR Documentation

Get all skeets in a thread

Description

Retrieve all skeets in a thread (all replies to an original skeet by any author). It does not matter if you use the original skeet or any reply as post_url.

Usage

get_thread(post_url, parse = TRUE, .token = NULL)

Arguments

post_url

the URL of any skeet in a thread.

parse

Parse the results or return the original nested object sent by the server.

.token

If you manage your own tokens, you can supply it here. Usually NULL is OK and will automatically load or guide you to generate a token.

Value

a data frame of skeets

Examples

## Not run: 
get_thread("https://bsky.app/profile/jbgruber.bsky.social/post/3kbi57u4sys2l")

## End(Not run)

atrrr documentation built on June 7, 2026, 1:06 a.m.