| get_user_info | R Documentation |
Query profile of an actor or actors
get_user_info(actor, parse = TRUE, .token = NULL)
actor |
user handle(s) to get information for. |
parse |
Parse the results or return the original nested object sent by the server. |
.token |
If you manage your own tokens, you can supply it here. Usually
|
Note that if you query several actors at once, profiles that do not (longer) exist will be missing from the results. If you query and individual actors and the profile is missing, the API will return an error and a message like "Account has been suspended".
a data frame (or nested list) of found actors.
## Not run:
rstats_user <- search_user("rstats", limit = 2L)
get_user_info(rstats_user$handle)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.